============
LSDTopyTools
============


.. image:: https://img.shields.io/pypi/v/lsdtopytools.svg
        :target: https://pypi.python.org/pypi/lsdtopytools

.. image:: https://img.shields.io/travis/bgailleton/lsdtopytools.svg
        :target: https://travis-ci.org/bgailleton/lsdtopytools

.. image:: https://readthedocs.org/projects/lsdtopytools/badge/?version=latest
        :target: https://lsdtopytools.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




High-level interface to LSDTopoTools in pyhton. Include as much tools as we can port in python, for the rest see our docker solutions


* Free software: GNU General Public License v3
* Documentation: https://lsdtopytools.readthedocs.io.


Features
--------

* TODO

Release Notes
-------------

So far, most of the releases are to fixe bug and slowly add functionnality for the alpha tester. I'll detail it when we will reach an acceptable stability.

Credits
-------

LSDTopoTools is a software package for analysing topography. Applications of these analyses span hydrology, geomorphology, soil science, ecology, and cognate fields. The software began within the Land Surface Dynamics group at the University of Edinburgh, and now has developers and users around the world. 

Documentation can be found there: https://lsdtopotools.github.io/LSDTT_documentation/

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
